@@ -14,7 +14,7 @@ import re
 
 from IPython.core.autocall import IPyAutocall
 from traitlets.config.configurable import Configurable
-from IPython.core.inputsplitter import (
+from IPython.core.inputtransformer2 import (
     ESC_MAGIC,
     ESC_QUOTE,
     ESC_QUOTE2,
@@ -82,7 +82,7 @@ class PrefilterManager(Configurable):
     prefilter consumes lines of input and produces transformed lines of
     input.
 
-    The iplementation consists of two phases:
+    The implementation consists of two phases:
 
     1. Transformers
     2. Checkers and handlers
