@@ -36,7 +36,6 @@ from IPython.utils.process import find_cmd
 # Globals
 #-----------------------------------------------------------------------------
 # This is used by every single test, no point repeating it ad nauseam
-ip = get_ipython()
 
 #-----------------------------------------------------------------------------
 # Tests
@@ -127,8 +126,8 @@ class InteractiveShellTestCase(unittest.TestCase):
         """Pretty-printing lists of objects with non-ascii reprs may cause
         problems."""
         class Spam(object):
-          def __repr__(self):
-            return "\xe9"*50
+            def __repr__(self):
+                return "\xe9"*50
         import IPython.core.formatters
         f = IPython.core.formatters.PlainTextFormatter()
         f([Spam(),Spam()])
@@ -530,6 +529,10 @@ class TestSafeExecfileNonAsciiPath(unittest.TestCase):
         ip.safe_execfile(self.fname, {}, raise_exceptions=True)
 
 class ExitCodeChecks(tt.TempFileMixin):
+
+    def setUp(self):
+        self.system = ip.system_raw
+
     def test_exit_code_ok(self):
         self.system('exit 0')
         self.assertEqual(ip.user_ns['_exit_code'], 0)
@@ -559,8 +562,11 @@ class ExitCodeChecks(tt.TempFileMixin):
                 del os.environ['SHELL']
 
 
-class TestSystemRaw(ExitCodeChecks, unittest.TestCase):
-    system = ip.system_raw
+class TestSystemRaw(ExitCodeChecks):
+
+    def setUp(self):
+        super().setUp()
+        self.sytem = ip.system_raw
 
     @onlyif_unicode_paths
     def test_1(self):
@@ -580,8 +586,11 @@ class TestSystemRaw(ExitCodeChecks, unittest.TestCase):
         self.assertEqual(ip.user_ns['_exit_code'], -signal.SIGINT)
 
 # TODO: Exit codes are currently ignored on Windows.
-class TestSystemPipedExitCode(ExitCodeChecks, unittest.TestCase):
-    system = ip.system_piped
+class TestSystemPipedExitCode(ExitCodeChecks):
+
+    def setUp(self):
+        super().setUp()
+        self.sytem = ip.system_piped
 
     @skip_win32
     def test_exit_code_ok(self):
@@ -595,7 +604,7 @@ class TestSystemPipedExitCode(ExitCodeChecks, unittest.TestCase):
     def test_exit_code_signal(self):
         ExitCodeChecks.test_exit_code_signal(self)
 
-class TestModules(tt.TempFileMixin, unittest.TestCase):
+class TestModules(tt.TempFileMixin):
     def test_extraneous_loads(self):
         """Test we're not loading modules on startup that we shouldn't.
         """
@@ -756,7 +765,7 @@ class TestAstTransformError(unittest.TestCase):
         err_transformer = ErrorTransformer()
         ip.ast_transformers.append(err_transformer)
         
-        with tt.AssertPrints("unregister", channel='stderr'):
+        with self.assertWarnsRegex(UserWarning, "It will be unregistered"):
             ip.run_cell("1 + 2")
         
         # This should have been removed.
@@ -872,9 +881,6 @@ def test_user_expression():
     
     # back to text only
     ip.display_formatter.active_types = ['text/plain']
-    
-
-
 
 
 class TestSyntaxErrorTransformer(unittest.TestCase):
@@ -908,25 +914,25 @@ class TestSyntaxErrorTransformer(unittest.TestCase):
             ip.run_cell('3456')
 
 
-
-def test_warning_suppression():
-    ip.run_cell("import warnings")
-    try:
-        with tt.AssertPrints("UserWarning: asdf", channel="stderr"):
-            ip.run_cell("warnings.warn('asdf')")
-        # Here's the real test -- if we run that again, we should get the
-        # warning again. Traditionally, each warning was only issued once per
-        # IPython session (approximately), even if the user typed in new and
-        # different code that should have also triggered the warning, leading
-        # to much confusion.
-        with tt.AssertPrints("UserWarning: asdf", channel="stderr"):
-            ip.run_cell("warnings.warn('asdf')")
-    finally:
-        ip.run_cell("del warnings")
+class TestWarningSupression(unittest.TestCase):
+    def test_warning_suppression(self):
+        ip.run_cell("import warnings")
+        try:
+            with self.assertWarnsRegex(UserWarning, "asdf"):
+                ip.run_cell("warnings.warn('asdf')")
+            # Here's the real test -- if we run that again, we should get the
+            # warning again. Traditionally, each warning was only issued once per
+            # IPython session (approximately), even if the user typed in new and
+            # different code that should have also triggered the warning, leading
+            # to much confusion.
+            with self.assertWarnsRegex(UserWarning, "asdf"):
+                ip.run_cell("warnings.warn('asdf')")
+        finally:
+            ip.run_cell("del warnings")
 
 
-def test_deprecation_warning():
-    ip.run_cell("""
+    def test_deprecation_warning(self):
+        ip.run_cell("""
 import warnings
 def wrn():
     warnings.warn(
@@ -934,17 +940,17 @@ def wrn():
         DeprecationWarning
     )
         """)
-    try:
-        with tt.AssertPrints("I AM  A WARNING", channel="stderr"):
-            ip.run_cell("wrn()")
-    finally:
-        ip.run_cell("del warnings")
-        ip.run_cell("del wrn")
+        try:
+            with self.assertWarnsRegex(DeprecationWarning, "I AM  A WARNING"):
+                ip.run_cell("wrn()")
+        finally:
+            ip.run_cell("del warnings")
+            ip.run_cell("del wrn")
 
 
 class TestImportNoDeprecate(tt.TempFileMixin):
 
-    def setup(self):
+    def setUp(self):
         """Make a valid python temp file."""
         self.mktmp("""
 import warnings
@@ -954,6 +960,7 @@ def wrn():
         DeprecationWarning
     )
 """)
+        super().setUp()
 
     def test_no_dep(self):
         """
