@@ -9,6 +9,7 @@ import os
 import re
 import sys
 import warnings
+from textwrap import dedent
 from unittest import TestCase
 from importlib import invalidate_caches
 from io import StringIO
@@ -32,9 +33,6 @@ from IPython.utils.tempdir import (TemporaryDirectory,
 from IPython.utils.process import find_cmd
 
 
-
-_ip = get_ipython()
-
 @magic.magics_class
 class DummyMagics(magic.Magics): pass
 
@@ -149,6 +147,7 @@ def test_rehashx():
     # rehashx must fill up syscmdlist
     scoms = _ip.db['syscmdlist']
     nt.assert_true(len(scoms) > 10)
+            
 
 
 def test_magic_parse_options():
@@ -401,6 +400,15 @@ def test_time():
         with tt.AssertPrints("hihi", suppress=False):
             ip.run_cell("f('hi')")
 
+def test_time_last_not_expression():
+    ip.run_cell("%%time\n"
+                "var_1 = 1\n"
+                "var_2 = 2\n")
+    assert ip.user_ns['var_1'] == 1
+    del ip.user_ns['var_1']
+    assert ip.user_ns['var_2'] == 2
+    del ip.user_ns['var_2']
+    
 
 @dec.skip_win32
 def test_time2():
@@ -419,6 +427,19 @@ def test_time3():
                     "run = 0\n"
                     "run += 1")
 
+def test_multiline_time():
+    """Make sure last statement from time return a value."""
+    ip = get_ipython()
+    ip.user_ns.pop('run', None)
+
+    ip.run_cell(dedent("""\
+        %%time
+        a = "ho"
+        b = "hey"
+        a+b
+        """))
+    nt.assert_equal(ip.user_ns_hidden['_'], 'hohey')
+
 def test_time_local_ns():
     """
     Test that local_ns is actually global_ns when running a cell magic
@@ -1151,8 +1172,8 @@ def test_time_no_var_expand():
 def test_timeit_arguments():
     "Test valid timeit arguments, should not cause SyntaxError (GH #1269)"
     if sys.version_info < (3,7):
-        _ip.magic("timeit ('#')")
+        _ip.magic("timeit -n1 -r1 ('#')")
     else:
         # 3.7 optimize no-op statement like above out, and complain there is
         # nothing in the for loop.
-        _ip.magic("timeit a=('#')")
+        _ip.magic("timeit -n1 -r1 a=('#')")
