@@ -9,17 +9,13 @@ import os
 import tempfile
 import shutil
 import subprocess
+from base64 import encodebytes
 
 from IPython.utils.process import find_cmd, FindCmdError
 from traitlets.config import get_config
 from traitlets.config.configurable import SingletonConfigurable
 from traitlets import List, Bool, Unicode
-from IPython.utils.py3compat import cast_unicode, cast_unicode_py2 as u, PY3
-
-try: # Py3
-    from base64 import encodebytes
-except ImportError: # Py2
-    from base64 import encodestring as encodebytes
+from IPython.utils.py3compat import cast_unicode
 
 
 class LaTeXTool(SingletonConfigurable):
@@ -165,25 +161,25 @@ def genelatex(body, wrap):
     """Generate LaTeX document for dvipng backend."""
     lt = LaTeXTool.instance()
     breqn = wrap and lt.use_breqn and kpsewhich("breqn.sty")
-    yield u(r'\documentclass{article}')
+    yield r'\documentclass{article}'
     packages = lt.packages
     if breqn:
         packages = packages + ['breqn']
     for pack in packages:
-        yield u(r'\usepackage{{{0}}}'.format(pack))
-    yield u(r'\pagestyle{empty}')
+        yield r'\usepackage{{{0}}}'.format(pack)
+    yield r'\pagestyle{empty}'
     if lt.preamble:
         yield lt.preamble
-    yield u(r'\begin{document}')
+    yield r'\begin{document}'
     if breqn:
-        yield u(r'\begin{dmath*}')
+        yield r'\begin{dmath*}'
         yield body
-        yield u(r'\end{dmath*}')
+        yield r'\end{dmath*}'
     elif wrap:
         yield u'$${0}$$'.format(body)
     else:
         yield body
-    yield u'\end{document}'
+    yield u'\\end{document}'
 
 
 _data_uri_template_png = u"""<img src="data:image/png;base64,%s" alt=%s />"""
